@@ -22,15 +22,15 @@ type RecordConfig struct {
 	// TTL is the DNS record's TTL in seconds. 0 means provider default.
 	TTL uint32 `json:"ttl,omitempty"`
 
-	// Name is the shortname i.e. the FQDN without the parent directory's suffix.
+	// Name is the shortname i.e. the FQDN without the parent domains's suffix.
 	// It should never be "".  Record at the apex (naked domain) are represented by "@".
+	NameRaw     string `json:"name_raw,omitempty"`     // .Name as the user entered it in dnsconfig.js
 	Name        string `json:"name"`                   // The short name, PunyCode. See above.
-	NameRaw     string `json:"name_raw,omitempty"`     // .Name as the user entered it in dnsconfig.js (downcased).
 	NameUnicode string `json:"name_unicode,omitempty"` // .Name as Unicode (downcased, then convertedot Unicode).
 
 	// This is the FQDN version of .Name. It should never have a trailing ".".
-	NameFQDN        string `json:"-"` // Must end with ".$origin".
 	NameFQDNRaw     string `json:"-"` // .NameFQDN as the user entered it in dnsconfig.js (downcased).
+	NameFQDN        string `json:"-"` // Must end with ".$origin".
 	NameFQDNUnicode string `json:"-"` // .NameFQDN as Unicode (downcased, then convertedot Unicode).
 
 	// F is the binary representation of the record's data usually a dns.XYZ struct.
@@ -67,7 +67,7 @@ type RecordConfig struct {
 	// getting the records via the API, we store the original object here.
 	// Later if we need to pull out an ID or other provider-specific field, we
 	// can.  Typically deleting or updating a record requires knowing its ID.
-	Original interface{} `json:"-"`
+	Original any `json:"-"`
 
 	//// Legacy fields we hope to remove someday
 
@@ -151,7 +151,7 @@ func (rc *RecordConfig) UnmarshalJSON(b []byte) error {
 		TTL       uint32            `json:"ttl,omitempty"`
 		Metadata  map[string]string `json:"meta,omitempty"`
 		FilePos   string            `json:"filepos"` // Where in the file this record was defined.
-		Original  interface{}       `json:"-"`       // Store pointer to provider-specific record object. Used in diffing.
+		Original  any               `json:"-"`       // Store pointer to provider-specific record object. Used in diffing.
 		Args      []any             `json:"args,omitempty"`
 
 		MxPreference       uint16            `json:"mxpreference,omitempty"`
@@ -236,6 +236,10 @@ func (rc *RecordConfig) UnmarshalJSON(b []byte) error {
 	return nil
 }
 
+// FixPosition takes the string representation of a position in a file that
+// comes from dnsconfig.js's initial execution, and reduces it down to just the
+// line/position we display to the user. The input is not well-defined, thus if
+// we find something we don't expect, we just return the original input.
 // TODO: Move this to rtypecontrol or a similar package.
 func FixPosition(str string) string {
 	if str == "" {
@@ -243,8 +247,9 @@ func FixPosition(str string) string {
 	}
 	str = strings.TrimSpace(str)
 	str = strings.ReplaceAll(str, "\n", " ")
-	str = strings.TrimPrefix(str, "at <anonymous>:")
-	return fmt.Sprintf("[line:%s]", str)
+	str = strings.ReplaceAll(str, "<anonymous>", "line")
+	str = strings.TrimPrefix(str, "at ")
+	return fmt.Sprintf("[%s]", str)
 }
 
 // Copy returns a deep copy of a RecordConfig.
@@ -352,17 +357,24 @@ func (rc *RecordConfig) ToComparableNoTTL() string {
 
 // ToRR converts a RecordConfig to a dns.RR.
 func (rc *RecordConfig) ToRR() dns.RR {
-	// IsModernType types store standard types as dns.RR directly in rc.F.
-	if rr, ok := rc.F.(dns.RR); ok {
-		return rr
-	}
-
-	// Don't call this on fake types.
+	// Function is not valid on pseudo-types.
 	rdtype, ok := dns.StringToType[rc.Type]
 	if !ok {
 		log.Fatalf("No such DNS type as (%#v)\n", rc.Type)
 	}
 
+	// If this IsModernType, the dns.RR is already in rc.F.
+	if rr, ok := rc.F.(dns.RR); ok {
+		rr.Header().Name = rc.NameFQDN + "."
+		rr.Header().Rrtype = rdtype
+		rr.Header().Class = dns.ClassINET
+		rr.Header().Ttl = rc.TTL
+		if rc.TTL == 0 {
+			rr.Header().Ttl = DefaultTTL
+		}
+		return rr
+	}
+
 	// Magically create an RR of the correct type.
 	rr := dns.TypeToRR[rdtype]()
 
@@ -536,8 +548,20 @@ func (rc *RecordConfig) GetSVCBValue() []dns.SVCBKeyValue {
 	return nil
 }
 
-// IsModernType returns true if this RecordConfig uses the new "F" field to store its rdata.
-// Once all record types have been migrated to use "F", this function can be removed.
+// IsModernType returns true if this RecordConfig is a record type implemented
+// in the new ("Modern") style (i.e. uses the RecordConfig .F field to store
+// the rdata of the record).
+//
+// Since this relies on .F, it must be used only after the RecordConfig
+// has been populated. Otherwise, use rtypecontrol.IsModernType(recordTypeName),
+// which takes the type name as input.
+//
+// NOTE: Do not confuse this with rtypeinfo.IsModernType() which provides
+// similar functionality.  This function is used to have a RecordConfig reveal
+// if it uses a modern type.  rtypeinfo.IsModernType() takes the rtype name as
+// a string argument.
+//
+// FUTURE(tlim): Once all record types have been migrated to use ".F", this function can be removed.
 func (rc *RecordConfig) IsModernType() bool {
 	return rc.F != nil
 }
