@@ -10,8 +10,8 @@ import (
 	"strings"
 
 	"github.com/StackExchange/dnscontrol/v4/models"
+	"github.com/StackExchange/dnscontrol/v4/pkg/providers"
 	"github.com/StackExchange/dnscontrol/v4/pkg/transform"
-	"github.com/StackExchange/dnscontrol/v4/providers"
 	"github.com/miekg/dns"
 	"github.com/miekg/dns/dnsutil"
 )
@@ -137,10 +137,8 @@ func checkLabel(label string, rType string, domain string, meta map[string]strin
 	// are used in a way we consider typical.  Yes, we're opinionated here.
 
 	// Don't warn for certain rtypes:
-	for _, ex := range []string{"SRV", "TLSA", "TXT", "LUA"} {
-		if rType == ex {
-			return nil
-		}
+	if slices.Contains([]string{"SRV", "TLSA", "TXT", "LUA"}, rType) {
+		return nil
 	}
 	// Don't warn for records that start with _
 	// See https://github.com/StackExchange/dnscontrol/issues/829
@@ -401,6 +399,7 @@ func ValidateAndNormalizeConfig(config *models.DNSConfig) (errs []error) {
 
 		// Normalize Records.
 		models.PostProcessRecords(domain.Records)
+		// No need to call FixLegacyDC here. These records were created from dnsconfig.js, not from a provider.
 		for _, rec := range domain.Records {
 			if rec.TTL == 0 {
 				rec.TTL = models.DefaultTTL
